@@ -72,17 +72,15 @@ class TestDjangoStatic(TestCase):
         settings.DJANGO_STATIC_SAVE_PREFIX = _original_DJANGO_STATIC_SAVE_PREFIX
         settings.DJANGO_STATIC_NAME_PREFIX = _original_DJANGO_STATIC_NAME_PREFIX
         settings.DJANGO_STATIC_MEDIA_URL = _original_DJANGO_STATIC_MEDIA_URL
+        settings.DJANGO_STATIC_FILE_PROXY = None
         
         assert settings.MEDIA_ROOT.startswith(gettempdir())
         rmtree(settings.MEDIA_ROOT)
         
         super(TestDjangoStatic, self).tearDown()
+        
 
         
-    #####################
-    ## Next generation 
-    #
-    
 
     def test__combine_filenames(self):
         """test the private function _combine_filenames()"""
@@ -599,7 +597,7 @@ class TestDjangoStatic(TestCase):
         filenames = ('/test_X.js', '/test_Y.js')
         codes = ('function (var1, var2)  { return var1+var2; }',
                  'var xxxxx = "yyyy" ;')
-
+        
         self._test_slimfile_multiple(filenames, codes, name_prefix='/infinity')
         
     def test_slimfile_multiple_debug_off_with_name_prefix(self):
@@ -1355,4 +1353,125 @@ class TestDjangoStatic(TestCase):
         del settings.DJANGO_STATIC_YUI_COMPRESSOR
         
         django_static.templatetags.django_static.Popen = old_Popen
+        
+    def test_load_file_proxy(self):
+        
+        settings.DEBUG = False
+        func = django_static.templatetags.django_static._load_file_proxy
+        
+        if hasattr(settings, 'DJANGO_STATIC_FILE_PROXY'):
+            del settings.DJANGO_STATIC_FILE_PROXY
+        
+        proxy_function = func()
+        self.assertEqual(proxy_function.func_name, 'file_proxy_nothing')
+        # this function will always return the first argument
+        self.assertEqual(proxy_function('anything', 'other', shit=123), 'anything')
+        self.assertEqual(proxy_function(None), None) 
+        self.assertEqual(proxy_function(123), 123)
+        self.assertRaises(TypeError, proxy_function)
+        self.assertRaises(TypeError, proxy_function, keyword='argument')
+        
+        # the same would happen if DJANGO_STATIC_FILE_PROXY is defined but 
+        # set to nothing
+        settings.DJANGO_STATIC_FILE_PROXY = None
+        proxy_function = func()
+        self.assertEqual(proxy_function.func_name, 'file_proxy_nothing')
+        
+        # Now set it to something sensible
+        # This becomes the equivalent of `from django_static.tests import fake_file_proxy`
+        # Test that that works to start with
+        from django_static.tests import fake_file_proxy
+        settings.DJANGO_STATIC_FILE_PROXY = 'django_static.tests.fake_file_proxy'
+        
+        proxy_function = func()
+        self.assertNotEqual(proxy_function.func_name, 'file_proxy_nothing')
+        
+        # but that's not enough, now we need to "monkey patch" this usage
+        django_static.templatetags.django_static.file_proxy = proxy_function
+        
+        # now with this set up it will start to proxy and staticfile() or slimfile()
+        
+        open(settings.MEDIA_ROOT + '/img100.gif', 'w').write(_GIF_CONTENT)
+        
+        template_as_string = """{% load django_static %}
+        {% staticfile "/img100.gif" %}
+        """        
+        template = Template(template_as_string)
+        context = Context()
+        rendered = template.render(context).strip()
+        self.assertEqual(_last_fake_file_uri, rendered)
+        
+        # we can expect that a keyword argument called 'filepath' was used
+        self.assertTrue('filepath' in _last_fake_file_keyword_arguments)
+        # the filepath should point to the real file
+        self.assertTrue(os.path.isfile(_last_fake_file_keyword_arguments['filepath']))
+        
+        self.assertTrue('new' in _last_fake_file_keyword_arguments)
+        self.assertTrue(_last_fake_file_keyword_arguments['new'])
+        
+        self.assertTrue('changed' in _last_fake_file_keyword_arguments)
+        self.assertFalse(_last_fake_file_keyword_arguments['changed'])
+        
+        self.assertTrue('checked' in _last_fake_file_keyword_arguments)
+        self.assertTrue(_last_fake_file_keyword_arguments['checked'])
+        
+        # if you run it again, because we're not in debug mode the second time
+        # the file won't be checked if it has changed
+        assert not settings.DEBUG
+        rendered = template.render(context).strip()
+        self.assertEqual(_last_fake_file_uri, rendered)
+        self.assertFalse(_last_fake_file_keyword_arguments['new'])
+        self.assertFalse(_last_fake_file_keyword_arguments['checked'])
+        self.assertFalse(_last_fake_file_keyword_arguments['changed'])
+        
+        # What if DJANGO_STATIC = False
+        # It should still go through the configured file proxy function
+        settings.DJANGO_STATIC = False
+        rendered = template.render(context).strip()
+        assert rendered == '/img100.gif'
+        self.assertFalse(_last_fake_file_keyword_arguments['checked'])
+        self.assertFalse(_last_fake_file_keyword_arguments['changed'])
+        
+    def test_file_proxy_with_name_prefix(self):
+        # Test it with a name prefix
+        settings.DEBUG = True
+        settings.DJANGO_STATIC = True
+        settings.DJANGO_STATIC_NAME_PREFIX = '/love-cache'
+        
+        open(settings.MEDIA_ROOT + '/imgXXX.gif', 'w').write(_GIF_CONTENT)
+        
+        # set up the file proxy
+        settings.DJANGO_STATIC_FILE_PROXY = 'django_static.tests.fake_file_proxy'
+        func = django_static.templatetags.django_static._load_file_proxy
+        proxy_function = func()
+        # but that's not enough, now we need to "monkey patch" this usage
+        django_static.templatetags.django_static.file_proxy = proxy_function
+        
+        template_as_string = """{% load django_static %}
+        {% staticfile "/imgXXX.gif" %}
+        """        
+        template = Template(template_as_string)
+        context = Context()
+        rendered = template.render(context).strip()
+        
+        self.assertEqual(_last_fake_file_uri, rendered)
+        self.assertTrue(_last_fake_file_keyword_arguments['new'])
+        self.assertTrue('filepath' in _last_fake_file_keyword_arguments)
+        
+        
+# These have to be mutable so that we can record that they have been used as 
+# global variables. 
+_last_fake_file_uri = None
+_last_fake_file_keyword_arguments = None
+
+def fake_file_proxy(uri, **k):
+    # reset the global mutables used to check that file_proxy() was called
+    global _last_fake_file_uri
+    global _last_fake_file_keyword_arguments
+    
+    _last_fake_file_uri = uri
+    _last_fake_file_keyword_arguments = k
+    return uri
+
+
 
